@@ -7,9 +7,9 @@ Created on Sun Jan  8 16:52:17 2023
 __all__ = ['archive.py', 'file.py', 'sudo.py', 'pip.py','ntp.py','piptools.py']
 import platform
 import os
-import sudo
 import archive
-import piptools
+import piptools,subprocess
+import winshell
 # logog=''''''
 # logoe=''''''
 
@@ -55,8 +55,15 @@ if __name__ == '__main__':
     __runfst__()
 
 
-def pshell(shell):
-    os.system("powershell " + shell)
+def python_call_powershell(file,*o):
+    try:
+        args=[r"powershell.exe","-ExecutionPolicy","Unrestricted", file,o]  #args参数里的ip是对应调用powershell里的动态参数args[0],类似python中的sys.argv[1]
+        p=subprocess.Popen(args, stdout=subprocess.PIPE)
+        dt=p.stdout.read()
+        return dt
+    except Exception as e:
+        print(e)
+    return False
 
 
 class clear:
@@ -64,9 +71,9 @@ class clear:
         os.system("cls")
 
 
-sudo = sudo.sudo
 unarchive = archive.unfile
 make_archive = archive.addfile
 pip_install = piptools.install
 pip_uninstall = piptools.uninstall
 pip_reinstall = piptools.reinstall
+pwh=winshell.powershell
