@@ -4,8 +4,8 @@ Created on Fri Jan 13 18:59:17 2023
 
 @author: Administrator
 """
-import ntplib,datetime
-def ct(url):
+import ntplib,datetime,sudo
+def __r(url):
     c = ntplib.NTPClient()
     
     hosts = ['edu.ntp.org.cn', 'tw.ntp.org.cn', 'us.ntp.org.cn', 'cn.pool.ntp.org', 'jp.ntp.org.cn']
@@ -39,4 +39,7 @@ def ct(url):
     _time = "%s:%s:%s" % (a, b, c)
     
     eval(r"os.system('date %s && time %s' % (_date, _time))")
-    print("同步后时间:", str(datetime.datetime.now())[:22])
\ No newline at end of file
+    print("同步后时间:", str(datetime.datetime.now())[:22])
+    class ct(url):
+        def __init__(url):
+            sudo.sudopy(__r(url))
\ No newline at end of file
